pygeodesy.geod3solve._Geodesic3SolveBase

Package pygeodesy :: Module geod3solve :: Class _Geodesic3SolveBase |
[frames] | no frames]

# Class _Geodesic3SolveBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
    solveBase._SolveCapsBase --+
                               |
            solveBase._SolveBase --+
                                   |
               solveBase._Solve3Base --+
                                       |
                                      _Geodesic3SolveBase

Known Subclasses:
  - Geodesic3Solve
  - , GeodesicLine3Solve

(INTERNAL) Base class for Geodesic3Solve and GeodesicLine3Solve.

Instance Methods
toStr(self, **prec_sep) Return this `Geodesic3Solve` as string. |
Inherited from `solveBase._SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| datum = `None` hash(x)
| ellipsoid = `None` hash(x)
| f = `None` hash(x)
| flattening = `None` hash(x)
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| a Get the triaxial's major radius, semi-axis (`meter`).
| b Get the triaxial's middle radius, semi-axis (`meter`).
| c Get the triaxial's minor radius, semi-axis (`meter`).
| Geod3Solve Get the Geod3Solve executable (`filename`).
Inherited from `solveBase._SolveBase`: `reverse2`, `unroll` Inherited from `solveBase._SolveCapsBase`: `Exact`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toStr (self, **prec_sep) |
Return this `Geodesic3Solve` as string. Arguments: `prec_sep` - See toStr. Returns: Geodesic3Solve items (`str`). Overrides: named._Named.toStr

Property Details

### a Get the triaxial's major radius, semi-axis (`meter`). Get method: a(self) - Get the triaxial's major radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### b Get the triaxial's middle radius, semi-axis (`meter`). Get method: b(self) - Get the triaxial's middle radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### c Get the triaxial's minor radius, semi-axis (`meter`). Get method: c(self) - Get the triaxial's minor radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Geod3Solve Get the Geod3Solve executable (`filename`). Get method: Geod3Solve(self) - Get the Geod3Solve executable (`filename`). Set method: Geod3Solve(self, path) - Set the Geod3Solve executable (`filename`), the (fully qualified) path to the `Geod3Solve` executable. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.